@@ -15,7 +15,7 @@ Usage::
     list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_shield.type_defs import (
     ListAttacksResponseTypeDef,
@@ -30,7 +30,7 @@ __all__ = ("ListAttacksPaginator", "ListProtectionsPaginator")
 
 class ListAttacksPaginator(Boto3Paginator):
     """
-    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/shield.html#Shield.Paginator.ListAttacks)
+    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/shield.html#Shield.Paginator.ListAttacks)
     """
 
     def paginate(
@@ -39,20 +39,20 @@ class ListAttacksPaginator(Boto3Paginator):
         StartTime: TimeRangeTypeDef = None,
         EndTime: TimeRangeTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListAttacksResponseTypeDef, None, None]:
+    ) -> Iterator[ListAttacksResponseTypeDef]:
         """
-        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
+        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
         """
 
 
 class ListProtectionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/shield.html#Shield.Paginator.ListProtections)
+    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/shield.html#Shield.Paginator.ListProtections)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListProtectionsResponseTypeDef, None, None]:
+    ) -> Iterator[ListProtectionsResponseTypeDef]:
         """
-        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
+        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
         """
